@@ -59,12 +59,13 @@ class App(ABC):
         else:
             log_level=logging.INFO
         logging.basicConfig(format='%(asctime)s %(name)-20s: %(levelname)-8s %(message)s', level=log_level, datefmt='%Y-%m-%d %H:%M:%S')
+        print("using log level " + log_level)
 
         if args.command is None:
             self.print_usage_info(str(args.port))
         elif args.command == 'deregister':
             if args.port is None:
-                self.print_usage_info(str(args.port), "--port is mandatory for deregister command")
+                self.print_usage_info(None, "--port is mandatory for deregister command")
             else:
                 self.unit.deregister(int(args.port))
         elif args.command == 'log':
